KEMEncapsulationResult class

KEM encapsulation result

Constructors

KEMEncapsulationResult({required Uint8List ciphertext, required Uint8List sharedSecret})
const

Properties

ciphertext → Uint8List
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedSecret → Uint8List
final

Methods

dispose() → void
Wipes the shared secret and ciphertext from the Dart heap.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHexStrings() → Map<String, String>
Alternative method that returns properties as hex strings
toString() → String
A string representation of this object.
inherited
toStrings() → Map<String, String>
Returns all Uint8List properties as base64 encoded strings

Operators

operator ==(Object other) → bool
The equality operator.
inherited